@@ -16,11 +16,11 @@ Net::Hacky::Detect::IP - Hackily try different methods of attaining local system
 
 =head1 VERSION
 
-Version 0.021
+Version 0.022
 
 =cut
 
-our $VERSION = '0.021';
+our $VERSION = '0.022';
 
 my $tools = {
     unix => {
@@ -291,21 +291,17 @@ sub _checkIP4 {
     return 0 if ($ip[2] < 0 || $ip[2] > 255);
     return 0 if ($ip[3] <= 0 || $ip[3] >= 255);
     
-    # Now lets try listen on the ip.. see if we can bind to it, try three times on
-    # random ports incase we bump into a busy one.
-    for (1..3) {
-        my $port = 1025+int(rand(64510));
-        my $sock = IO::Socket::IP->new(
-            Domain      =>  PF_INET,
-            LocalAddr   =>  $host,
-            LocalPort   =>  $port,
-            Proto       =>  'tcp',
-            ReuseAddr   =>  1
-        );
-        if ($sock) {
-            $bindsuccess=1;
-            last;
-        }
+    # Bind port 0 'Select the first one availible'
+    my $port = 0;
+    my $sock = IO::Socket::IP->new(
+        Domain      =>  PF_INET,
+        LocalAddr   =>  $host,
+        LocalPort   =>  $port,
+        Proto       =>  'tcp',
+        ReuseAddr   =>  1
+    );
+    if ($sock) {
+        $bindsuccess=1;
     }
 
     return $bindsuccess;
@@ -323,23 +319,19 @@ sub _checkIP6 {
     # By default fail the bind
     my $bindsuccess = 0;
 
-   # Now lets try listen on the ip.. see if we can bind to it, try three times on
-    # random ports incase we bump into a busy one.
-    for (1..3) {
-        my $port = 1025+int(rand(64510));
-        my $sock = IO::Socket::IP->new(
-            Domain      =>  PF_INET6,
-            LocalAddr   =>  $host,
-            LocalPort   =>  $port,
-            Proto       =>  'tcp',
-            ReuseAddr   =>  1
-        );
-        if ($sock) {
-            $bindsuccess=1;
-            last;
-        }
+   # Bind port 0 'Select the first one availible'
+    my $port = 0;
+    my $sock = IO::Socket::IP->new(
+        Domain      =>  PF_INET6,
+        LocalAddr   =>  $host,
+        LocalPort   =>  $port,
+        Proto       =>  'tcp',
+        ReuseAddr   =>  1
+    );
+    if ($sock) {
+        $bindsuccess=1;
     }
-    
+
     return $bindsuccess;
 }
 
